@@ -1,4 +1,4 @@
-# Copyrights 2011-2014 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::Compile::SOAP::WSS;
-our $VERSION = '1.12';
+use vars '$VERSION';
+$VERSION = '1.13';
 
 use base 'XML::Compile::SOAP::Extension';
 
@@ -52,6 +53,10 @@ sub soap11OperationInit($$)
         or error __x"WSS not connected to the WSDL: WSS needs to be instantiated
 before the WSDL because it influences its interpretation";
 
+    # this is not a nice hack for apps where multiple ::WSDL or ::Schema
+    # objects are active https://rt.cpan.org/Ticket/Display.html?id=99735
+    $schema eq $op->schemas or return;
+
     trace "adding wss header logic";  # get full type from any schema
     my $sec = $schema->findName('wsse:Security');
     $op->addHeader(INPUT  => "wsse_Security" => $sec, mustUnderstand => 1);
@@ -61,6 +66,9 @@ before the WSDL because it influences its interpretation";
 
 sub soap11ClientWrapper($$$)
 {   my ($self, $op, $call, $args) = @_;
+
+    $self->schema eq $op->schemas or return;
+
     sub {
         my $data = @_==1 ? shift : {@_};
         my $sec  = $data->{wsse_Security};
