@@ -1,4 +1,4 @@
-# Copyrights 2011-2014 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::Compile::WSS;
-our $VERSION = '1.12';
+use vars '$VERSION';
+$VERSION = '1.13';
 
 
 use Log::Report 'xml-compile-wss';
@@ -16,8 +17,6 @@ use XML::Compile::Util      qw/SCHEMA2001/;
 use XML::Compile::Schema::BuiltInTypes qw/builtin_type_info/;
 
 use File::Basename          qw/dirname/;
-use Encode                  qw/encode/;
-use MIME::Base64            qw/encode_base64/;
 use POSIX                   qw/strftime/;
 use Scalar::Util            qw/weaken/;
 
@@ -179,7 +178,11 @@ sub loadSchemas($$)
 __PATCH
 
     $schema->allowUndeclared(1);
-    $schema->addCompileOptions(RW => mixed_elements => 'STRUCTURAL');
+    $schema->addCompileOptions('RW'
+      , mixed_elements     => 'STRUCTURAL'
+      , ignore_unused_tags => qr/^wsu_Id$/
+      );
+
     $schema->anyElement('ATTEMPT');
     $schema;
 }
@@ -188,20 +191,28 @@ __PATCH
 sub writerHookWsuId($)
 {   my ($self, $type) = @_;
 
-    my $wrapper = sub
-      { my ($doc, $values, $path, $tag, $r) = @_ ;
+    my $after = sub
+      { my ($doc, $node, $path, $val) = @_;
 
-        # Remove $id first, to avoid $r complaining about unused
-        my $id   = delete $values->{wsu_Id};
-        my $node = $r->($doc, $values);
-        if($id)
-        {   $node->setNamespace(WSU_10, 'wsu', 0);
-            $node->setAttributeNS(WSU_10, 'Id' => $id);
+        my $id = $val->{wsu_Id};
+        defined $id or return $node;
+
+        # Some schema explicitly list wsu:Id attributes, we shouldn't add
+        # the attribute again.
+        if(my $has = $node->getAttributeNS(WSU_10, 'Id')
+                  || $node->getAttribute('wsu:Id'))
+        {   $has eq $id or warning __x"two wsu:Id attributes: {one} and {two}"
+               , one => $id, two => $has;
+
+            return $node;
         }
+
+        $node->setNamespace(WSU_10, 'wsu', 0);
+        $node->setAttributeNS(WSU_10, 'Id', $id);
         $node;
       };
 
-     +{ type => $type, replace => $wrapper };
+     +{ action => 'WRITER', type => $type, after => $after };
 }
 
 #---------------------------
