@@ -1,4 +1,4 @@
-# Copyrights 2011-2014 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::Compile::WSS::BasicAuth;
-our $VERSION = '1.12';
+use vars '$VERSION';
+$VERSION = '1.13';
 
 use base 'XML::Compile::WSS';
 
@@ -65,7 +66,7 @@ sub prepareWriting($)
     my $make_nonce = sub {
         my ($doc, $nonce) = @_;
         my $enc = encode_base64 $nonce;
-        $enc    =~ s/\n$//;
+        chomp $enc;
         $w_nonce->($doc, {_ => $enc, EncodingType => WSM10_BASE64});
     };
 
