@@ -1,4 +1,4 @@
-# Copyrights 2011-2014 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::Compile::WSS::Timestamp;
-our $VERSION = '1.12';
+use vars '$VERSION';
+$VERSION = '1.13';
 
 use base 'XML::Compile::WSS';
 
@@ -56,8 +57,9 @@ sub prepareWriting($)
     return if $self->{XCWT_stamp};
 
     my $ts_type = $schema->findName('wsu:Timestamp') ;
-    my $make_ts = $schema->writer($ts_type, include_namespaces => 1,
-      , hook => $self->writerHookWsuId('wsu:TimestampType'));
+    my @hooks   = $self->writerHookWsuId('wsu:TimestampType');
+    my $make_ts = $schema->writer($ts_type, include_namespaces => 1
+      , hooks => \@hooks);
     $schema->prefixFor(WSU_10);
 
     $self->{XCWT_stamp} = sub {
